@@ -3,7 +3,7 @@ use crate::utils::{read_s, Pod};
 
 #[derive(Debug, Clone)]
 pub enum ParseRelError {
-    BadArray,
+    BrokenEntry,
 }
 
 /// Rel section.
@@ -15,7 +15,7 @@ pub struct Rel<'a, T: Context> {
 impl<'a, T: Context> Rel<'a, T> {
     pub fn parse(content: &'a [u8]) -> Result<Self, ParseRelError> {
         use ParseRelError::*;
-        let entries = read_s(content).ok_or(BadArray)?;
+        let entries = read_s(content).ok_or(BrokenEntry)?;
         Ok(Self { entries })
     }
     pub fn entries(&self) -> &'a [RelEntry<T>] {
