@@ -4,16 +4,16 @@ use zelf::ident::Ident;
 #[path = "../utils/show.rs"]
 mod show;
 
-pub fn show(file: &str) -> Result<(), Box<dyn Error>> {
-    use zelf::elf::Elfs::{self, *};
+fn show(file: &str) -> Result<(), Box<dyn Error>> {
+    use zelf::elf::Elf::{self, *};
     use zelf::ident::ParseIdentError::*;
     let bytes = std::fs::read(file)?;
     match Ident::parse(&bytes) {
-        Err(BadHeader | BadPropertyMagic) => return Ok(()),
+        Err(BrokenHeader | BadPropertyMagic) => return Ok(()),
         _ => (),
     }
     println!("File Name: {}", file);
-    match Elfs::parse(&bytes).unwrap() {
+    match Elf::parse(&bytes).unwrap() {
         Little32(elf) => show::show(elf),
         Little64(elf) => show::show(elf),
         Big32(elf) => show::show(elf),
@@ -22,6 +22,7 @@ pub fn show(file: &str) -> Result<(), Box<dyn Error>> {
     Ok(())
 }
 
+#[cfg(target_os = "linux")]
 #[test]
 fn linux() {
     let usr_lib = std::fs::read_dir("/usr/lib").unwrap().into_iter();
@@ -31,6 +32,6 @@ fn linux() {
         if !each.file_type().unwrap().is_file() {
             continue;
         }
-        if let Err(_) = show(format!("/usr/bin/{}", each.file_name().to_str().unwrap()).as_str()) {}
+        if let Err(_) = show(&format!("/usr/bin/{}", each.file_name().to_str().unwrap())) {}
     }
 }
